@@ -103,6 +103,7 @@ static gint custom_attr_cmp_func (GtkTreeModel *model, GtkTreeIter *a,
 								  GtkTreeIter *b, gpointer userdata)
  {
 	gchar *name1, *name2;
+	gint res;
 
 	gtk_tree_model_get(model, a, CUSTOM_ATTR_NAME, &name1, -1);
 	gtk_tree_model_get(model, b, CUSTOM_ATTR_NAME, &name2, -1);
@@ -113,7 +114,11 @@ static gint custom_attr_cmp_func (GtkTreeModel *model, GtkTreeIter *a,
 	if (name2 == NULL)
 		return 1;
 	
-	return g_utf8_collate(name1, name2);
+	res = g_utf8_collate(name1, name2);
+	g_free(name1);
+	g_free(name2);
+
+	return res;
 }
 
 static GtkListStore* custom_attr_window_create_data_store(void)
@@ -155,7 +160,7 @@ static void custom_attr_window_list_view_clear_list(GtkWidget *list_view, gboole
 {
 	if (!warn || alertpanel(_("Delete all attribute names"),
 		       _("Do you really want to delete all attribute names?"),
-		       GTK_STOCK_CANCEL, GTK_STOCK_DELETE, NULL) == G_ALERTALTERNATE) {
+		       GTK_STOCK_CANCEL, GTK_STOCK_DELETE, NULL, ALERTFOCUS_FIRST) == G_ALERTALTERNATE) {
 		GtkListStore *list_store = GTK_LIST_STORE(gtk_tree_view_get_model
 						(GTK_TREE_VIEW(list_view)));
 		gtk_list_store_clear(list_store);
@@ -180,7 +185,7 @@ static void custom_attr_popup_delete (void *obj, void *data)
 
 	if (alertpanel(_("Delete attribute name"),
 		       _("Do you really want to delete this attribute name?"),
-		       GTK_STOCK_CANCEL, GTK_STOCK_DELETE, NULL) == G_ALERTALTERNATE) {
+		       GTK_STOCK_CANCEL, GTK_STOCK_DELETE, NULL, ALERTFOCUS_FIRST) == G_ALERTALTERNATE) {
 		gtk_list_store_remove(GTK_LIST_STORE(model), &sel);
 		dirty = TRUE;
 	}
@@ -190,7 +195,7 @@ static void custom_attr_popup_factory_defaults (void *obj, void *data)
 {
 	if (alertpanel(_("Reset to default"),
 		       _("Do you really want to replace all attribute names\nwith the default set?"),
-		       GTK_STOCK_NO, GTK_STOCK_YES, NULL) == G_ALERTALTERNATE) {
+		       GTK_STOCK_NO, GTK_STOCK_YES, NULL, ALERTFOCUS_FIRST) == G_ALERTALTERNATE) {
 		GList *tmp = custom_attr_default_list();
 		custom_attr_window_load_list(tmp);
 		if (tmp) {
@@ -208,7 +213,7 @@ static void custom_attr_popup_factory_defaults (void *obj, void *data)
 
 static GtkActionEntry custom_attr_popup_entries[] =
 {
-	{"CustomAttrPopup",			NULL, "CustomAttrPopup" },
+	{"CustomAttrPopup",			NULL, "CustomAttrPopup", NULL, NULL, NULL },
 	{"CustomAttrPopup/Delete",		NULL, N_("_Delete"), NULL, NULL, G_CALLBACK(custom_attr_popup_delete) },
 	{"CustomAttrPopup/DeleteAll",		NULL, N_("Delete _all"), NULL, NULL, G_CALLBACK(custom_attr_popup_clear_list) },
 	{"CustomAttrPopup/Reset",		NULL, N_("_Reset to default"), NULL, NULL, G_CALLBACK(custom_attr_popup_factory_defaults) },
@@ -347,8 +352,10 @@ static gboolean find_attr_in_store(GtkTreeModel *model,
 	if (g_utf8_collate(data->attr, attr)==0) {
 		data->path = path; /* signal we found it */
 		data->iter = *iter;
+		g_free(attr);
 		return TRUE;
 	}
+	g_free(attr);
 	return FALSE; 
 }
 
@@ -580,6 +587,7 @@ static gboolean custom_attr_store_to_glist (GtkTreeModel *model,
 	gtk_tree_model_get(model, iter, CUSTOM_ATTR_NAME, &attr, -1);
 	if (attr) {
 		store_to_glist = g_list_prepend(store_to_glist, g_strdup(attr));
+		g_free(attr);
 	}
 	return FALSE;
 }
