@@ -157,6 +157,7 @@ static void addressbook_foldersel_create( void )
 	gtk_container_set_border_width( GTK_CONTAINER(window), 0 );
 	gtk_window_set_title( GTK_WINDOW(window), _("Select Address Book Folder") );
 	gtk_window_set_position( GTK_WINDOW(window), GTK_WIN_POS_MOUSE );
+	gtk_window_set_type_hint(GTK_WINDOW(window), GDK_WINDOW_TYPE_HINT_DIALOG);
 	g_signal_connect( G_OBJECT(window), "delete_event",
 			  G_CALLBACK(addressbook_foldersel_delete_event), NULL );
 	g_signal_connect( G_OBJECT(window), "key_press_event",
@@ -183,6 +184,8 @@ static void addressbook_foldersel_create( void )
 			GDK_TYPE_PIXBUF, G_TYPE_STRING, G_TYPE_POINTER);
 
 	view = gtk_tree_view_new_with_model(GTK_TREE_MODEL(store));
+	gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(store), COL_NAME, GTK_SORT_ASCENDING);
+	gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(view), prefs_common.use_stripes_everywhere);
 	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(view), TRUE);
 	gtk_tree_view_set_enable_tree_lines(GTK_TREE_VIEW(view), FALSE);
 	gtk_tree_view_set_search_column(GTK_TREE_VIEW(view), COL_NAME);
