@@ -162,6 +162,8 @@ static gint addrindex_write_to			( AddressIndex *addrIndex,
  */
 typedef struct _AddressIfFrag AddressIfFragment;
 struct _AddressIfFrag {
+	AddressBookType type;
+	AddressCache *addressCache;
 	gchar *name;
 	GList *children;
 	GList *attributes;
@@ -1013,6 +1015,8 @@ static AddressIfFragment *addrindex_read_fragment( XMLFile *file ) {
 
 	/* Create new fragment */
 	fragment = g_new0( AddressIfFragment, 1 );
+	fragment->type = ADBOOKTYPE_NONE;
+	fragment->addressCache = NULL;
 	fragment->name = g_strdup( xtag->tag );
 	fragment->children = NULL;
 	fragment->attributes = NULL;
@@ -1291,7 +1295,7 @@ static void addrindex_parse_ldap_attrlist( XMLFile *file, LdapControl *ctl ) {
 		rc = xml_parse_next_tag( file );
 		if( rc != 0 ) {
 			/* Terminate prematurely */
-			mgu_free_dlist( list );
+			g_list_free_full( list, g_free );
 			list = NULL;
 			return;
 		}
@@ -2956,8 +2960,8 @@ gboolean addrindex_load_completion(
 					nodeM = g_list_next( nodeM );
 				}
 			}
-			/* Free up the list */
-			mgu_clear_list( items );
+			/* Free up the list (but not the data inside the
+			 * individual list items) */
 			g_list_free( items );
 
 			return TRUE;
