@@ -89,7 +89,7 @@
 #define USERS_ML_ADDR		"users@lists.claws-mail.org"
 #define USERS_ML_URI		"https://lists.claws-mail.org/cgi-bin/mailman/listinfo/users"
 #define GPL_URI			"https://www.gnu.org/licenses/gpl.html"
-#define DONATE_URI		"https://www.claws-mail.org/sponsors.php"
+#define DONATE_URI		"https://www.claws-mail.org/donations.php"
 #define CONFIG_VERSIONS_URI	"https://www.claws-mail.org/cvc.php"
 #define RELEASE_NOTES_FILE	"RELEASE_NOTES"
 #define THEMEINFO_FILE		".claws_themeinfo"
@@ -140,12 +140,6 @@
 #  define MAXPATHLEN			4095
 #endif
 
-#define DEFAULT_HEIGHT			460
-#define DEFAULT_FOLDERVIEW_WIDTH	179
-#define DEFAULT_MAINVIEW_WIDTH		600
-#define DEFAULT_SUMMARY_HEIGHT		140
-#define DEFAULT_HEADERVIEW_HEIGHT	40
-#define DEFAULT_COMPOSE_HEIGHT		560
 #define BORDER_WIDTH			2
 #define CTREE_INDENT			18
 #define FOLDER_SPACING			4
