@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2016 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2020 The Claws Mail Team and Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@
 
 #ifdef HAVE_CONFIG_H
 #include "claws-features.h"
+#include "config.h"
 #endif
 
 #ifdef HAVE_BACKTRACE
@@ -47,10 +48,13 @@
 #  include <wchar.h>
 #endif
 
-/* The Hurd doesn't have this limit */
+/* The Hurd doesn't have these limits */
 #ifndef PATH_MAX
   #define PATH_MAX 4196
 #endif
+#ifndef HOST_NAME_MAX
+  #define HOST_NAME_MAX 256
+#endif
 
 #ifdef G_OS_WIN32
 
@@ -68,25 +72,6 @@ typedef gint64 goffset;
 #define G_MAXOFFSET	G_MAXINT64
 #endif
 
-#ifndef HAVE_U32_TYPEDEF
-  #undef u32	    /* maybe there is a macro with this name */
-  typedef guint32 u32;
-  #define HAVE_U32_TYPEDEF
-#endif
-
-#if !GLIB_CHECK_VERSION(2, 26, 0)
-#define g_base64_decode(t,l)	g_base64_decode_wa((t),(l))
-guchar *g_base64_decode_wa(const gchar *text, gsize *out_len);
-#endif
-
-#if !GLIB_CHECK_VERSION(2, 25, 0)
-# ifdef G_OS_WIN32
-	typedef _g_stat_struct GStatBuf;
-# else
-	typedef struct stat GStatBuf;
-# endif
-#endif
-
 #ifndef BIG_ENDIAN_HOST
   #if (G_BYTE_ORDER == G_BIG_ENDIAN)
     #define BIG_ENDIAN_HOST 1
@@ -140,7 +125,7 @@ guchar *g_base64_decode_wa(const gchar *text, gsize *out_len);
 		g_warning("can't allocate memory"); \
 		iffail; \
 	} else { \
-		strncpy(__tmp, str, len); \
+		memcpy(__tmp, str, len); \
 		__tmp[len] = '\0'; \
 	} \
  \
@@ -266,11 +251,6 @@ gboolean debug_get_mode		(void);
 #define Str(x)	#x
 #define Xstr(x)	Str(x)
 
-
-/* System related stuff.  */
-
-gboolean superuser_p (void);
-
 /* List utilities. */
 
 GSList *slist_copy_deep		(GSList		*list,
@@ -278,8 +258,7 @@ GSList *slist_copy_deep		(GSList		*list,
 
 /* String utilities.  */
 
-void list_free_strings		(GList		*list);
-void slist_free_strings		(GSList		*list);
+void list_free_strings_full		(GList		*list);
 void slist_free_strings_full	(GSList		*list);
 
 void hash_free_strings		(GHashTable	*table);
@@ -288,8 +267,6 @@ gint str_case_equal		(gconstpointer	 v,
 				 gconstpointer	 v2);
 guint str_case_hash		(gconstpointer	 key);
 
-void ptr_array_free_strings	(GPtrArray	*array);
-
 /* number-string conversion */
 gint to_number			(const gchar *nstr);
 gchar *itos_buf			(gchar	     *nstr,
@@ -298,19 +275,16 @@ gchar *itos			(gint	      n);
 gchar *to_human_readable	(goffset      size);
 
 /* alternative string functions */
-gint strcmp2		(const gchar	*s1,
-			 const gchar	*s2);
-gchar *strstr2		(const gchar	*s1,
-			 const gchar	*s2);
 gint path_cmp		(const gchar	*s1,
 			 const gchar	*s2);
 gchar *strretchomp	(gchar		*str);
 gchar *strtailchomp	(gchar		*str,
 			 gchar		 tail_char);
 gchar *strcrchomp	(gchar		*str);
-gint file_strip_crs	(const gchar 	*file);
+#ifndef HAVE_STRCASESTR
 gchar *strcasestr	(const gchar	*haystack,
 			 const gchar	*needle);
+#endif /* HAVE_STRCASESTR */
 gchar *strncasestr	(const gchar	*haystack,
 			 gint		 haystack_len,
 			 const gchar	*needle);
@@ -369,8 +343,8 @@ void unfold_line			(gchar		*str);
 void subst_char				(gchar		*str,
 					 gchar		 orig,
 					 gchar		 subst);
-void subst_chars			(gchar 		*str, 	
-					 gchar 		*orig, 
+void subst_chars			(gchar 		*str,
+					 gchar 		*orig,
 					 gchar 		subst);
 void subst_for_filename			(gchar		*str);
 void subst_for_shellsafe_filename	(gchar		*str);
@@ -396,8 +370,8 @@ gchar *get_uri_path			(const gchar	*uri);
 gint get_uri_len			(const gchar	*str);
 void decode_uri				(gchar		*decoded_uri,
 					 const gchar	*encoded_uri);
-void decode_uri_with_plus		(gchar 		*decoded_uri, 
-					 const gchar 	*encoded_uri, 
+void decode_uri_with_plus		(gchar 		*decoded_uri,
+					 const gchar 	*encoded_uri,
 					 gboolean 	 with_plus);
 gint scan_mailto_url			(const gchar	*mailto,
 					 gchar	       **from,
@@ -424,6 +398,7 @@ const gchar *get_tmp_dir		(void);
 const gchar *get_locale_dir		(void);
 gchar *get_tmp_file			(void);
 const gchar *get_domain_name		(void);
+gboolean is_numeric_host_address	(const gchar *hostaddress);
 const gchar *get_desktop_file(void);
 #ifdef G_OS_WIN32
 const gchar *w32_get_themes_dir    (void);
@@ -438,6 +413,7 @@ gboolean file_exist		(const gchar	*file,
 gboolean is_relative_filename   (const gchar *file);
 gboolean is_dir_exist		(const gchar	*dir);
 gboolean is_file_entry_exist	(const gchar	*file);
+gboolean is_file_entry_regular(const gchar *file);
 gboolean dirent_is_regular_file	(struct dirent	*d);
 
 #define is_file_exist(file)		file_exist(file, FALSE)
@@ -454,50 +430,11 @@ gint remove_numbered_files_not_in_list(const gchar *dir,
 				       GSList *numberlist);
 gint remove_all_numbered_files	(const gchar	*dir);
 gint remove_dir_recursive	(const gchar	*dir);
-gint append_file		(const gchar	*src,
-				 const gchar	*dest,
-				 gboolean	 keep_backup);
-gint rename_force		(const gchar	*oldpath,
-				 const gchar	*newpath);
-gint copy_file			(const gchar	*src,
-				 const gchar	*dest,
-				 gboolean	 keep_backup);
-gint move_file			(const gchar	*src,
-				 const gchar	*dest,
-				 gboolean	 overwrite);
-gint copy_dir			(const gchar	*src,
-				 const gchar	*dest);
-gint copy_file_part_to_fp	(FILE		*fp,
-				 off_t		 offset,
-				 size_t		 length,
-				 FILE		*dest_fp);
-gint copy_file_part		(FILE		*fp,
-				 off_t		 offset,
-				 size_t		 length,
-				 const gchar	*dest);
-
 gchar *canonicalize_str		(const gchar	*str);
-gint canonicalize_file		(const gchar	*src,
-				 const gchar	*dest);
-gint canonicalize_file_replace	(const gchar	*file);
-
 gchar *normalize_newlines	(const gchar	*str);
 
 gchar *get_outgoing_rfc2822_str	(FILE		*fp);
 
-gint change_file_mode_rw	(FILE		*fp,
-				 const gchar	*file);
-FILE *my_tmpfile		(void);
-FILE *get_tmpfile_in_dir	(const gchar 	*dir,
-				 gchar	       **filename);
-FILE *str_open_as_stream	(const gchar	*str);
-gint str_write_to_file		(const gchar	*str,
-				 const gchar	*file);
-gchar *file_read_to_str		(const gchar	*file);
-gchar *file_read_stream_to_str	(FILE		*fp);
-gchar *file_read_to_str_no_recode(const gchar *file);
-gchar *file_read_stream_to_str_no_recode(FILE *fp);
-
 char *fgets_crlf(char *buf, int size, FILE *stream);
 
 /* process execution */
@@ -520,9 +457,9 @@ void get_rfc822_date		(gchar		*buf,
 void get_rfc822_date_hide_tz	(gchar		*buf,
 				 gint		 len);
 
-size_t fast_strftime		(gchar 			*buf, 
-				 gint 			 buflen, 
-				 const gchar 		*format, 
+size_t fast_strftime		(gchar 			*buf,
+				 gint 			 buflen,
+				 const gchar 		*format,
 				 struct tm 		*lt);
 
 /* debugging */
@@ -558,7 +495,7 @@ void get_hex_str(gchar *out, guchar ch);
 typedef struct AutoPointer	GAuto;
 GType g_auto_pointer_register		(void);
 GAuto *g_auto_pointer_new		(gpointer pointer);
-GAuto *g_auto_pointer_new_with_free	(gpointer p, 
+GAuto *g_auto_pointer_new_with_free	(gpointer p,
 					 GFreeFunc free);
 gpointer g_auto_pointer_get_ptr		(GAuto *auto_ptr);
 GAuto *g_auto_pointer_copy		(GAuto *auto_ptr);
@@ -571,9 +508,9 @@ gboolean get_uri_part	(const gchar *start,
 		   	 gboolean hdr);
 gchar *make_uri_string	(const gchar *bp,
 			 const gchar *ep);
-gboolean get_email_part	(const gchar *start, 
+gboolean get_email_part	(const gchar *start,
 			 const gchar *scanpos,
-			 const gchar **bp, 
+			 const gchar **bp,
 			 const gchar **ep,
 			 gboolean hdr);
 gchar *make_email_string(const gchar *bp,
@@ -581,7 +518,7 @@ gchar *make_email_string(const gchar *bp,
 gchar *make_http_string (const gchar *bp,
 			 const gchar *ep);
 
-gchar *mailcap_get_command_for_type(const gchar *type, 
+gchar *mailcap_get_command_for_type(const gchar *type,
 				    const gchar *file_to_open);
 void mailcap_update_default	   (const gchar *type,
 				    const gchar *command);
@@ -590,8 +527,6 @@ gboolean file_is_email(const gchar *filename);
 gboolean sc_g_list_bigger(GList *list, gint max);
 gboolean sc_g_slist_bigger(GSList *list, gint max);
 
-int claws_unlink(const gchar *filename);
-
 GMutex *cm_mutex_new(void);
 void cm_mutex_free(GMutex *mutex);
 
@@ -611,4 +546,10 @@ gboolean get_random_bytes(void *buf, size_t count);
 }
 #endif
 
+gboolean get_serverportfp_from_filename(const gchar *str, gchar **server, gchar **port, gchar **fp);
+
+#ifdef G_OS_WIN32
+gchar *win32_debug_log_path(void);
+#endif
+
 #endif /* __UTILS_H__ */
