@@ -102,6 +102,8 @@ GType gtk_vscrollbutton_get_type(void)
 			sizeof (GtkVScrollbutton),
 			0,	/* n_preallocs */
 			(GInstanceInitFunc) gtk_vscrollbutton_init,
+
+			(const GTypeValueTable *) NULL	/* value table */
 	};
 
 	vscrollbutton_type = g_type_register_static (GTK_TYPE_VBOX, "GtkVScrollbutton", &vscrollbutton_info, (GTypeFlags)0);
@@ -158,8 +160,8 @@ static void gtk_vscrollbutton_init(GtkVScrollbutton *scrollbutton)
     gtk_widget_show(arrow);
     gtk_container_add(GTK_CONTAINER(scrollbutton->downbutton), arrow);
     gtk_widget_set_size_request(scrollbutton->downbutton, -1, 16);
-    gtkut_widget_set_can_focus(scrollbutton->upbutton, FALSE);
-    gtkut_widget_set_can_focus(scrollbutton->downbutton, FALSE);
+    gtk_widget_set_can_focus(scrollbutton->upbutton, FALSE);
+    gtk_widget_set_can_focus(scrollbutton->downbutton, FALSE);
     gtk_widget_show(scrollbutton->downbutton);
     gtk_widget_show(scrollbutton->upbutton);
 
