@@ -430,7 +430,7 @@ static void resource_request_starting_cb(WebKitWebView		*view,
 	if ((!g_ascii_strncasecmp(uri, "cid:", 4)) || (!g_ascii_strncasecmp(uri, "mid:", 4))) {
 		image = g_strconcat("<", uri + 4, ">", NULL);
 		while ((partinfo = procmime_mimeinfo_next(partinfo)) != NULL) {
-			if (!g_ascii_strcasecmp(image, partinfo->id)) {
+			if (partinfo->id && !g_ascii_strcasecmp(image, partinfo->id)) {
 				filename = procmime_get_tmp_file_name(partinfo);
 				if (!filename) {
 					g_free(image);
@@ -457,7 +457,7 @@ static void resource_request_starting_cb(WebKitWebView		*view,
 		webkit_network_request_set_uri(request, "about:blank");
 	}
 	else
-		debug_print("Starting request of %zu %s\n", strlen(uri), uri);
+		debug_print("Starting request of %"G_GSIZE_FORMAT" %s\n", strlen(uri), uri);
 }
 
 static gboolean fancy_text_search(MimeViewer *_viewer, gboolean backward,
@@ -665,6 +665,7 @@ static void *download_file_curl (void *data)
 		curl_easy_setopt(curl, CURLOPT_WRITEFUNCTION, download_file_curl_write_cb);
 		curl_easy_setopt(curl, CURLOPT_WRITEDATA, viewer);
 		curl_easy_setopt(curl, CURLOPT_VERBOSE, 1L);
+		curl_easy_setopt(curl, CURLOPT_FOLLOWLOCATION, 1L);
 		res = curl_easy_perform(curl);
 		curl_easy_cleanup(curl);
 
@@ -690,6 +691,10 @@ static void download_file_cb(GtkWidget *widget, FancyViewer *viewer)
 	gchar *filename = g_utf8_strchr(link, -1, g_utf8_get_char("/"));
 	filename = g_strconcat(g_get_home_dir(), filename, NULL);
 	gchar *fname = filesel_select_file_save(_("Save as"), filename);
+	if (!fname) {
+		g_free(filename);
+		return;
+	}
 
 	if (viewer->curlfile) viewer->curlfile = NULL;
 	if (viewer->stream) viewer->stream = NULL;
@@ -747,10 +752,7 @@ static void viewer_menu_handler(GtkWidget *menuitem, FancyViewer *viewer)
 		if (!g_ascii_strcasecmp(gtk_label_get_text(GTK_LABEL(menul)),
 					"Open Link" )) {
 
-			if (viewer->override_prefs_remote_content)
-				gtk_label_set_text(GTK_LABEL(menul), _("Open in Viewer"));
-			else
-				gtk_label_set_text(GTK_LABEL(menul), _("Open in Viewer (enable remote content)"));
+			gtk_label_set_text(GTK_LABEL(menul), _("Open in Viewer"));
 
 			GtkImageMenuItem *m_new = GTK_IMAGE_MENU_ITEM(menuitem);
 			gtk_widget_set_sensitive(GTK_WIDGET(m_new), viewer->override_prefs_remote_content);
