@@ -174,7 +174,6 @@ static void prefs_gpg_create_widget_func(PrefsPage *_page,
 	gtk_widget_show(spinbtn_store_passphrase);
 	gtk_box_pack_start(GTK_BOX(hbox1), spinbtn_store_passphrase, FALSE,
 			   FALSE, 0);
-	gtk_widget_set_size_request(spinbtn_store_passphrase, 64, -1);
 	CLAWS_SET_TIP(spinbtn_store_passphrase,
 		      _("Setting to '0' will store the passphrase for the whole session"));
 	gtk_spin_button_set_numeric(GTK_SPIN_BUTTON
@@ -298,8 +297,6 @@ void key_custom_toggled(GtkToggleButton *togglebutton, gpointer user_data)
 	active = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(page->key_custom));
 	gtk_widget_set_sensitive(GTK_WIDGET(page->keyid_label), active);
 	gtk_widget_set_sensitive(GTK_WIDGET(page->keyid), active);
-	if (!active)
-		gtk_editable_delete_text(GTK_EDITABLE(page->keyid), 0, -1);
 }
 
 static void prefs_gpg_update_sens(struct GPGAccountPage *page)
@@ -492,9 +489,9 @@ static void prefs_gpg_account_save_func(PrefsPage *_page)
 			config->smime_sign_key = SIGN_KEY_BY_FROM;
 		else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(page->key_custom))) {
 			config->smime_sign_key = SIGN_KEY_CUSTOM;
-			g_free(config->smime_sign_key_id);
-			config->smime_sign_key_id = gtk_editable_get_chars(GTK_EDITABLE(page->keyid), 0, -1);
 		}
+		g_free(config->smime_sign_key_id);
+		config->smime_sign_key_id = gtk_editable_get_chars(GTK_EDITABLE(page->keyid), 0, -1);
 	} else {
 		if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(page->key_default)))
 			config->sign_key = SIGN_KEY_DEFAULT;
@@ -502,9 +499,9 @@ static void prefs_gpg_account_save_func(PrefsPage *_page)
 			config->sign_key = SIGN_KEY_BY_FROM;
 		else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(page->key_custom))) {
 			config->sign_key = SIGN_KEY_CUSTOM;
-			g_free(config->sign_key_id);
-			config->sign_key_id = gtk_editable_get_chars(GTK_EDITABLE(page->keyid), 0, -1);
 		}
+		g_free(config->sign_key_id);
+		config->sign_key_id = gtk_editable_get_chars(GTK_EDITABLE(page->keyid), 0, -1);
 	}
 
 	prefs_gpg_account_set_config(page->account, config);
@@ -559,14 +556,16 @@ struct GPGAccountConfig *prefs_gpg_account_get_config(PrefsAccount *account)
 		if (strv[0] != NULL) {
 			if (!strcmp(strv[0], "DEFAULT"))
 				config->sign_key = SIGN_KEY_DEFAULT;
-			if (!strcmp(strv[0], "BY_FROM"))
+			else if (!strcmp(strv[0], "BY_FROM"))
 				config->sign_key = SIGN_KEY_BY_FROM;
-			if (!strcmp(strv[0], "CUSTOM")) {
-				if (strv[1] != NULL) {
-					config->sign_key = SIGN_KEY_CUSTOM;
-					config->sign_key_id = g_strdup(strv[1]);
-				} else
-					config->sign_key = SIGN_KEY_DEFAULT;
+			else if (!strcmp(strv[0], "CUSTOM")) {
+				config->sign_key = SIGN_KEY_CUSTOM;
+			} else {
+				config->sign_key = SIGN_KEY_DEFAULT;
+			}
+
+			if (strv[1] != NULL) {
+				config->sign_key_id = g_strdup(strv[1]);
 			}
 		}
 		g_strfreev(strv);
@@ -583,14 +582,16 @@ struct GPGAccountConfig *prefs_gpg_account_get_config(PrefsAccount *account)
 		if (strv[0] != NULL) {
 			if (!strcmp(strv[0], "DEFAULT"))
 				config->smime_sign_key = SIGN_KEY_DEFAULT;
-			if (!strcmp(strv[0], "BY_FROM"))
+			else if (!strcmp(strv[0], "BY_FROM"))
 				config->smime_sign_key = SIGN_KEY_BY_FROM;
-			if (!strcmp(strv[0], "CUSTOM")) {
-				if (strv[1] != NULL) {
-					config->smime_sign_key = SIGN_KEY_CUSTOM;
-					config->smime_sign_key_id = g_strdup(strv[1]);
-				} else
-					config->smime_sign_key = SIGN_KEY_DEFAULT;
+			else if (!strcmp(strv[0], "CUSTOM")) {
+				config->smime_sign_key = SIGN_KEY_CUSTOM;
+			} else {
+				config->smime_sign_key = SIGN_KEY_DEFAULT;
+			}
+
+			if (strv[1] != NULL) {
+				config->smime_sign_key_id = g_strdup(strv[1]);
 			}
 		}
 		g_strfreev(strv);
@@ -605,10 +606,10 @@ void prefs_gpg_account_set_config(PrefsAccount *account, GPGAccountConfig *confi
 
 	switch (config->sign_key) {
 	case SIGN_KEY_DEFAULT:
-		confstr = g_strdup("DEFAULT");
+		confstr = g_strdup_printf("DEFAULT;%s", config->sign_key_id);
 		break;
 	case SIGN_KEY_BY_FROM:
-		confstr = g_strdup("BY_FROM");
+		confstr = g_strdup_printf("BY_FROM;%s", config->sign_key_id);
 		break;
 	case SIGN_KEY_CUSTOM:
 		confstr = g_strdup_printf("CUSTOM;%s", config->sign_key_id);
@@ -625,10 +626,10 @@ void prefs_gpg_account_set_config(PrefsAccount *account, GPGAccountConfig *confi
 
 	switch (config->smime_sign_key) {
 	case SIGN_KEY_DEFAULT:
-		confstr = g_strdup("DEFAULT");
+		confstr = g_strdup_printf("DEFAULT;%s", config->smime_sign_key_id);
 		break;
 	case SIGN_KEY_BY_FROM:
-		confstr = g_strdup("BY_FROM");
+		confstr = g_strdup_printf("BY_FROM;%s", config->smime_sign_key_id);
 		break;
 	case SIGN_KEY_CUSTOM:
 		confstr = g_strdup_printf("CUSTOM;%s", config->smime_sign_key_id);
