@@ -55,6 +55,7 @@ FeedItem *rssyl_parse_folder_item_file(gchar *path)
 	FeedItem *item;
 	RFeedCtx *ctx;
 	gint i = 0;
+	GString *body = NULL;
 	gboolean parsing_headers = TRUE, past_html_tag = FALSE, past_endhtml_tag = FALSE;
 	gboolean started_author = FALSE, started_subject = FALSE;
 	gboolean started_link = FALSE, started_clink = FALSE, got_original_title = FALSE;
@@ -137,7 +138,7 @@ FeedItem *rssyl_parse_folder_item_file(gchar *path)
 				/* Last-Seen timestamp */
 				if( !strcmp(line[0], "X-RSSyl-Last-Seen") ) {
 					ctx->last_seen = atol(line[1]);
-					debug_print("RSSyl: got last_seen timestamp %lld\n", (long long)ctx->last_seen);
+					debug_print("RSSyl: got last_seen timestamp %"G_GSIZE_FORMAT"\n", ctx->last_seen);
 				}
 
 				/* ID */
@@ -197,6 +198,7 @@ FeedItem *rssyl_parse_folder_item_file(gchar *path)
 			if( !strcmp(lines[i], RSSYL_TEXT_START) ) {
 				debug_print("RSSyl: Leading html tag found at line %d\n", i);
 				past_html_tag = TRUE;
+				body = g_string_new("");
 				i++;
 				continue;
 			}
@@ -204,29 +206,27 @@ FeedItem *rssyl_parse_folder_item_file(gchar *path)
 				if( !strcmp(lines[i], RSSYL_TEXT_END) ) {
 					debug_print("RSSyl: Trailing html tag found at line %d\n", i);
 					past_endhtml_tag = TRUE;
-					i++;
 					continue;
 				}
-				if( feed_item_get_text(item) != NULL ) {
-					gint e_len, n_len;
-					e_len = strlen(item->text);
-					n_len = strlen(lines[i]);
-					item->text = g_realloc(item->text, e_len + n_len + 2);
-					*(item->text+e_len) = '\n';
-					strcpy(item->text+e_len+1, lines[i]);
-					*(item->text+e_len+n_len+1) = '\0';
-				} else {
-					item->text = g_strdup(lines[i]);
-				}
+
+				if (body->len > 0)
+					body = g_string_append_c(body, '\n');
+				body = g_string_append(body, lines[i]);
+
 				i++;
 			}
 
-			if( lines[i] == NULL )
-				return item;
 		}
 
 		i++;
 	}
+
+	if (body != NULL ) {
+		if (past_html_tag && past_endhtml_tag && body->str != NULL)
+			feed_item_set_text(item, body->str);
+		g_string_free(body, TRUE);
+	}
+
 	g_free(lines);
 	g_free(contents);
 	return item;
