@@ -297,7 +297,7 @@ static gboolean tnef_parse (MimeParser *parser, MimeInfo *mimeinfo)
 	if (mimeinfo->content == MIMECONTENT_FILE)
 		debug_print("content: %s\n", mimeinfo->data.filename);
 	else 
-		debug_print("contents in memory (len %zd)\n", 
+		debug_print("contents in memory (len %"G_GSIZE_FORMAT")\n", 
 			strlen(mimeinfo->data.mem));
 	
 	tnef = g_new0(TNEFStruct, 1);
