@@ -22,7 +22,6 @@
 #include "claws-features.h"
 #endif
 
-#define _GNU_SOURCE
 #include <stdio.h>
 
 #include <glib.h>
@@ -42,6 +41,7 @@
 #include "gtkutils.h"
 #include "password.h"
 #include "codeconv.h"
+#include "file-utils.h"
 
 #define CL(x)	(((gulong) (x) >> (gulong) 8) & 0xFFUL)
 #define RGB_FROM_GDK_COLOR(c) \
@@ -49,12 +49,6 @@
 	 (CL(c.green) << (gulong)  8) | \
 	 (CL(c.blue)))
 
-#ifdef HAVE_FGETS_UNLOCKED
-#define SC_FGETS fgets_unlocked
-#else
-#define SC_FGETS fgets
-#endif
-
 typedef enum
 {
 	DUMMY_PARAM
@@ -91,19 +85,15 @@ void prefs_read_config(PrefParam *param, const gchar *label,
 			return;
 	}
 
-	if ((fp = g_fopen(rcfile, "rb")) == NULL) {
-		if (ENOENT != errno) FILE_OP_ERROR(rcfile, "fopen");
+	if ((fp = claws_fopen(rcfile, "rb")) == NULL) {
+		if (ENOENT != errno) FILE_OP_ERROR(rcfile, "claws_fopen");
 		return;
 	}
 
 	block_label = g_strdup_printf("[%s]", label);
 
-#ifdef HAVE_FGETS_UNLOCKED
-	flockfile(fp);
-#endif
-
 	/* search aiming block */
-	while (SC_FGETS(buf, sizeof(buf), fp) != NULL) {
+	while (claws_fgets(buf, sizeof(buf), fp) != NULL) {
 		gint val;
 
 		if (encoding) {
@@ -125,7 +115,7 @@ void prefs_read_config(PrefParam *param, const gchar *label,
 	}
 	g_free(block_label);
 
-	while (SC_FGETS(buf, sizeof(buf), fp) != NULL) {
+	while (claws_fgets(buf, sizeof(buf), fp) != NULL) {
 		strretchomp(buf);
 		/* reached next block */
 		if (buf[0] == '[') break;
@@ -145,10 +135,7 @@ void prefs_read_config(PrefParam *param, const gchar *label,
 	}
 
 	debug_print("Finished reading configuration.\n");
-#ifdef HAVE_FGETS_UNLOCKED
-	funlockfile(fp);
-#endif
-	fclose(fp);
+	claws_fclose(fp);
 }
 
 static void prefs_config_parse_one_line(PrefParam *param, const gchar *buf)
@@ -227,7 +214,7 @@ static void prefs_config_parse_one_line(PrefParam *param, const gchar *buf)
 if (!(func)) \
 { \
 	g_warning("Failed to write configuration to file"); \
-	if (orig_fp) fclose(orig_fp); \
+	if (orig_fp) claws_fclose(orig_fp); \
 	prefs_file_close_revert(pfile); \
 	g_free(rcpath); \
 	g_free(block_label); \
@@ -249,13 +236,13 @@ void prefs_write_config(PrefParam *param, const gchar *label,
 	cm_return_if_fail(rcfile != NULL);
 
 	rcpath = g_strconcat(get_rc_dir(), G_DIR_SEPARATOR_S, rcfile, NULL);
-	if ((orig_fp = g_fopen(rcpath, "rb")) == NULL) {
-		if (ENOENT != errno) FILE_OP_ERROR(rcpath, "fopen");
+	if ((orig_fp = claws_fopen(rcpath, "rb")) == NULL) {
+		if (ENOENT != errno) FILE_OP_ERROR(rcpath, "claws_fopen");
 	}
 
 	if ((pfile = prefs_write_open(rcpath)) == NULL) {
 		g_warning("Failed to write configuration to file");
-		if (orig_fp) fclose(orig_fp);
+		if (orig_fp) claws_fclose(orig_fp);
 		g_free(rcpath);
 		return;
 	}
@@ -264,7 +251,7 @@ void prefs_write_config(PrefParam *param, const gchar *label,
 
 	/* search aiming block */
 	if (orig_fp) {
-		while (fgets(buf, sizeof(buf), orig_fp) != NULL) {
+		while (claws_fgets(buf, sizeof(buf), orig_fp) != NULL) {
 			gint val;
 
 			val = strncmp(buf, block_label, strlen(block_label));
@@ -273,7 +260,7 @@ void prefs_write_config(PrefParam *param, const gchar *label,
 				block_matched = TRUE;
 				break;
 			} else
-				TRY(fputs(buf, pfile->fp) != EOF);
+				TRY(claws_fputs(buf, pfile->fp) != EOF);
 		}
 	}
 
@@ -284,15 +271,15 @@ void prefs_write_config(PrefParam *param, const gchar *label,
 
 	if (block_matched) {
 		gboolean in_dup_block = FALSE;
-		while (fgets(buf, sizeof(buf), orig_fp) != NULL) {
+		while (claws_fgets(buf, sizeof(buf), orig_fp) != NULL) {
 			/* next block */
 			if (buf[0] == '[') {
-				TRY(fputc('\n', pfile->fp) != EOF &&
-				    fputs(buf, pfile->fp)  != EOF);
+				TRY(claws_fputc('\n', pfile->fp) != EOF &&
+				    claws_fputs(buf, pfile->fp)  != EOF);
 				break;
 			}
 		}
-		while (fgets(buf, sizeof(buf), orig_fp) != NULL) {
+		while (claws_fgets(buf, sizeof(buf), orig_fp) != NULL) {
 			if (buf[0] == '[') {
 				if (!strncmp(buf, block_label,
 						strlen(block_label)))
@@ -301,14 +288,14 @@ void prefs_write_config(PrefParam *param, const gchar *label,
 					in_dup_block = FALSE;
 			}
 			if (!in_dup_block)
-				TRY(fputs(buf, pfile->fp) != EOF);
+				TRY(claws_fputs(buf, pfile->fp) != EOF);
 		}
 	}
 
 	g_free(block_label);
 	block_label = NULL;
 
-	if (orig_fp) fclose(orig_fp);
+	if (orig_fp) claws_fclose(orig_fp);
 	if (prefs_file_close(pfile) < 0)
 		g_warning("Failed to write configuration to file");
 	g_free(rcpath);
@@ -375,8 +362,8 @@ gint prefs_write_param(PrefParam *param, FILE *fp)
 		}
 
 		if (buf[0] != '\0') {
-			if (fputs(buf, fp) == EOF) {
-				perror("fputs");
+			if (claws_fputs(buf, fp) == EOF) {
+				perror("claws_fputs");
 				return -1;
 			}
 		}
@@ -939,17 +926,13 @@ static int prefs_cache_sections(GHashTable *file_cache, const gchar *rcfile)
 	GHashTable *section_cache = NULL;
 
 	if (rcfile)
-		fp = g_fopen(rcfile, "rb");
+		fp = claws_fopen(rcfile, "rb");
 	if (!fp) {
 		debug_print("cache: %s: %s\n", rcfile?rcfile:"(null)", g_strerror(errno));
 		return -1;
 	}
-	
-#ifdef HAVE_FGETS_UNLOCKED
-	flockfile(fp);
-#endif
-	
-	while (SC_FGETS(buf, sizeof(buf), fp) != NULL) {
+		
+	while (claws_fgets(buf, sizeof(buf), fp) != NULL) {
 		strretchomp(buf);
 		if (buf[0] == '\0')
 			continue;
@@ -991,10 +974,7 @@ static int prefs_cache_sections(GHashTable *file_cache, const gchar *rcfile)
 			}
 		}
 	}
-#ifdef HAVE_FGETS_UNLOCKED
-	funlockfile(fp);
-#endif
-	fclose(fp);
+	claws_fclose(fp);
 	return 0;
 }
 
