@@ -91,9 +91,11 @@ static gboolean _select_by_data_func(GtkTreeModel *model, GtkTreePath *path,
 	gtk_tree_model_get(GTK_TREE_MODEL(model), iter, COMBOBOX_DATA, &curdata, -1);
 	if ( data != NULL && curdata != NULL && !strcmp(data, curdata) ) {
 		gtk_combo_box_set_active_iter(combobox, iter);
+		g_free(curdata);
 		return TRUE;
 	}
 
+	g_free(curdata);
 	return FALSE;
 }
 
@@ -126,6 +128,8 @@ static gboolean _combobox_separator_func(GtkTreeModel *model,
 
 	if( txt == NULL )
 		return TRUE;
+
+	g_free(txt);
 	return FALSE;
 }
 
@@ -202,7 +206,7 @@ static void prefs_send_create_widget(PrefsPage *_page, GtkWindow *window,
 	gtk_widget_show (hbox1);
 
 	PACK_CHECK_BUTTON(hbox1, checkbtn_warn_multiple_recipients,
-			_("Warn when sending to more recipients than:"));
+			_("Warn when sending to more recipients than"));
 
 	spinbtn_warn_multiple_recipients = gtk_spin_button_new_with_range(2, 999, 1);
 	gtk_widget_show(spinbtn_warn_multiple_recipients);
