@@ -423,6 +423,7 @@ static gboolean cb_preview(GtkPrintOperation        *operation,
 		geometry.min_width = 600;
 		geometry.min_height = 400;
 	}
+	gtk_window_set_type_hint(GTK_WINDOW(dialog), GDK_WINDOW_TYPE_HINT_DIALOG);
 	gtk_window_set_geometry_hints(GTK_WINDOW(dialog), NULL, &geometry,
 				      GDK_HINT_MIN_SIZE);
 	gtk_widget_set_size_request(dialog, prefs_common.print_previewwin_width,
@@ -1121,16 +1122,18 @@ static void printing_textview_cb_draw_page(GtkPrintOperation *op, GtkPrintContex
 		GdkPixbuf *pixbuf = gtk_image_get_pixbuf(print_data->avatar);
 		gdouble startx, starty;
 		
-		startx = gtk_print_context_get_width(context)/print_data->zoom;
+		if (pixbuf != NULL) {
+			startx = gtk_print_context_get_width(context)/print_data->zoom;
 		
-		startx -= ((double)gdk_pixbuf_get_width(pixbuf));
+			startx -= ((double)gdk_pixbuf_get_width(pixbuf));
 
-		starty = start_pos;
+			starty = start_pos;
 
-		surface = pixbuf_to_surface(pixbuf);
-		cairo_set_source_surface (cr, surface, startx, starty);
-		cairo_paint (cr);
-		cairo_surface_destroy (surface);
+			surface = pixbuf_to_surface(pixbuf);
+			cairo_set_source_surface (cr, surface, startx, starty);
+			cairo_paint (cr);
+			cairo_surface_destroy (surface);
+		}
 	}
 
 	pango_layout_iter_free(iter);
